pub struct NodeModulesPathMatcher;Expand description
Matches anything inside of a node_modules directory.
Package managers churn node_modules heavily while the dev server is running. More aggressively
batching these may reduce system load during an installation.
Implementations
Sourceimpl NodeModulesPathMatcher
impl NodeModulesPathMatcher
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
ResolvedVc.
Cell is selected based on the value type and call order of cell.